<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Evet',
    'no' => 'Hayır',
    'update' => 'Güncelle',
    'save' => 'Kaydet',
    'add' => 'Ekle',
    'cancel' => 'Vazgeç',
    'confirm' => 'Doğrula',
    'delete_confirm' => 'Emin misiniz?',
    'delete' => 'Sil',
    'edit' => 'Düzenle',
    'upload' => 'Yükle',
    'download' => 'İndir',
    'save_close' => 'Kaydet ve kapat',
    'close' => 'Kapat',
    'copy' => 'Kopyala',
    'create' => 'Oluştur',
    'remove' => 'Kaldır',
    'revoke' => 'Geri al',
    'done' => 'Bitti',
    'back' => 'Geri',
    'verify' => 'Doğrula',
    'new' => 'yeni',
    'unknown' => 'Bilmiyorum',
    'load_more' => 'Daha fazla',
    'loading' => 'Yükleniyor…',
    'with' => 'ile',
    'today' => 'bugün',
    'yesterday' => 'dün',
    'another_day' => 'başka bir gün',
    'date' => 'Tarih',
    'type' => 'Tip',
    'zoom' => 'Yakınlaştır',
    'upgrade' => 'Kilidi açmak için yükselt',
    'percent_uploaded' => '%{percent} yüklendi',
    'retry' => 'Tekrar dene',
    'filter' => 'Listeyi filtrele',
    'go_back' => 'Geri dön',
    'file_selected' => '{count} dosya seçildi…',

    'application_title' => 'Monica - kişisel ilişki yöneticisi',
    'application_description' => 'Monica sevdiklerinizle, arkadaşlarınızla ve ailenizle etkileşimlerinizi yönetebileceğiniz bir araçtır.',
    'application_og_title' => 'Sevdiklerinizle daha iyi ilişkiler kurun. Arkadaşlarınız ve aileniz için ücretsiz Online CRM.',

    'markdown_description' => 'Metninizi güzel bir şekilde biçimlendirmek mi istiyorsunuz? Kalın, italik, listeler ve daha fazlasını eklemek için Markdown desteğimiz bulunmaktadır.',
    'markdown_link' => 'Dokümantasyonu oku',

    'header_settings_link' => 'Ayarlar',
    'header_logout_link' => 'Çıkış yap',
    'header_changelog_link' => 'Ürün değişiklikleri',

    'main_nav_cta' => 'Kişi ekle',
    'main_nav_dashboard' => 'Kontrol paneli',
    'main_nav_family' => 'Kişiler',
    'main_nav_journal' => 'Günlük',
    'main_nav_activities' => 'Aktiviteler',
    'main_nav_tasks' => 'Görevler',

    'footer_remarks' => 'Yorumlar?',
    'footer_send_email' => 'Bize e-posta gönderin',
    'footer_privacy' => 'Gizlilik politikası',
    'footer_release' => 'Sürüm notları',
    'footer_newsletter' => 'Haber Bülteni',
    'footer_source_code' => 'Katkıda bulun',
    'footer_version' => 'Sürüm: :version',
    'footer_new_version' => 'Monica\'nın yeni sürümü mevcut',

    'footer_modal_version_whats_new' => 'Neler yeni',
    'footer_modal_version_release_away' => 'Mevcut olan son sürümden 1 sürüm aşağıdasın. Uygulamanı güncellemelisin.|Mevcut olan son sürümden :number sürüm aşağıdasın. Uygulamanı güncellemelisin.',

    'breadcrumb_dashboard' => 'Başlangıç',
    'breadcrumb_list_contacts' => 'Kişi Listesi',
    'breadcrumb_archived_contacts' => 'Arşivli kişiler',
    'breadcrumb_journal' => 'Günlük',
    'breadcrumb_settings' => 'Ayarlar',
    'breadcrumb_settings_export' => 'Dışa aktar',
    'breadcrumb_settings_users' => 'Kullanıcılar',
    'breadcrumb_settings_users_add' => 'Bir kullanıcı ekle',
    'breadcrumb_settings_subscriptions' => 'Abonelik',
    'breadcrumb_settings_import' => 'İçe aktar',
    'breadcrumb_settings_import_report' => 'İçe aktarım raporu',
    'breadcrumb_settings_import_upload' => 'Yükle',
    'breadcrumb_settings_tags' => 'Etiketler',
    'breadcrumb_add_significant_other' => 'Sevgili ekle',
    'breadcrumb_edit_significant_other' => 'Sevgiliyi düzenle',
    'breadcrumb_add_note' => 'Bir not ekle',
    'breadcrumb_edit_note' => 'Bir notu düzenle',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV Kaynakları',
    'breadcrumb_edit_introductions' => 'Nasıl tanıştınız',
    'breadcrumb_settings_personalization' => 'Kişiselleştirme',
    'breadcrumb_settings_security' => 'Güvenlik',
    'breadcrumb_settings_security_2fa' => 'İki Aşamalı Doğrulama',
    'breadcrumb_profile' => ':name kişisinin Profili',

    'gender_male' => 'Erkek',
    'gender_female' => 'Kadın',
    'gender_none' => 'Söylemek istemiyorum',
    'gender_no_gender' => 'Cinsiyetsiz',

    'error_title' => 'Amanın! Bir şeyler ters gitti.',
    'error_unauthorized' => 'Bu kaynağı düzenlemeye yetkiniz yok.',
    'error_user_account' => 'Kullanıcı belirli bir role sahip değil.',
    'error_save' => 'Verileri kaydetmeye çalışırken bir hata oluştu.',
    'error_try_again' => 'Bir şeyler ters gitti. Lütfen tekrar deneyin.',
    'error_id' => 'Hata kimliği: :id',
    'error_unavailable' => 'Hizmet kullanılamıyor',
    'error_maintenance' => 'Bakım devam ediyor. Birazdan geri döneceğiz.',
    'error_help' => 'Kısa süre sonra geri döneceğiz.',
    'error_twitter' => 'Yeniden çalışır olduğunda haberdar olmak için <a href="https://twitter.com/:twitter">Twitter hesabımızı</a> takip edin.',
    'error_no_term' => 'Bu olay için henüz bir politika yok.',

    'default_save_success' => 'Veri kaydedildi.',

    'compliance_title' => 'Rahatsız ettiğimiz için üzgünüz.',
    'compliance_desc' => '<a href=":urlterm" hreflang=":hreflang">Kullanım Koşullarımızı</a> ve <a href=":url" hreflang=":hreflang">Gizlilik Politikamızı</a> değiştirdik. Yasalara göre, sizden hesabınızı kullanmaya devam edebilmeniz için onları gözden geçirmenizi ve kabul etmenizi istemek zorundayız.',
    'compliance_desc_end' => 'Verileriniz veya hesabınızla ilgili kötü bir şey yapmıyoruz ve asla yapmayacağız.',
    'compliance_terms' => 'Yeni şartları ve gizlilik politikasını kabul et',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Aşk İlişkileri',
    'relationship_type_group_family' => 'Aile İlişkileri',
    'relationship_type_group_friend' => 'Arkadaşlık İlişkileri',
    'relationship_type_group_work' => 'İş İlişkileri',
    'relationship_type_group_other' => 'Diğer tür ilişkiler',

    'relationship_type_partner' => 'sevgili',
    'relationship_type_partner_female' => 'sevgili',
    'relationship_type_partner_male' => 'significant other',
    'relationship_type_partner_with_name' => ':name kişisinin sevgilisi',
    'relationship_type_partner_female_with_name' => ':name kişisinin sevgilisi',
    'relationship_type_partner_male_with_name' => ':name’s significant other',

    'relationship_type_spouse' => 'eş',
    'relationship_type_spouse_female' => 'wife',
    'relationship_type_spouse_male' => 'husband',
    'relationship_type_spouse_with_name' => ':name kişisinin eşi',
    'relationship_type_spouse_female_with_name' => ':name’s wife',
    'relationship_type_spouse_male_with_name' => ':name’s husband',

    'relationship_type_date' => 'flört',
    'relationship_type_date_female' => 'flört',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => ':name kişisinin flörtü',
    'relationship_type_date_female_with_name' => ':name kişisinin flörtü',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'aşık',
    'relationship_type_lover_female' => 'aşık',
    'relationship_type_lover_male' => 'lover',
    'relationship_type_lover_with_name' => ':name kişisinin aşığı',
    'relationship_type_lover_female_with_name' => ':name kişisinin aşığı',
    'relationship_type_lover_male_with_name' => ':name’s lover',

    'relationship_type_inlovewith' => 'aşık olduğu',
    'relationship_type_inlovewith_female' => 'aşık olduğu',
    'relationship_type_inlovewith_male' => 'in love with',
    'relationship_type_inlovewith_with_name' => ':name kişisinin aşık olduğu kişi',
    'relationship_type_inlovewith_female_with_name' => ':name kişisinin aşık olduğu kişi',
    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',

    'relationship_type_lovedby' => 'gizli aşık',
    'relationship_type_lovedby_female' => 'gizli aşık',
    'relationship_type_lovedby_male' => 'loved by',
    'relationship_type_lovedby_with_name' => ':name kişisinin gizli aşığı',
    'relationship_type_lovedby_female_with_name' => ':name kişisinin gizli aşığı',
    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',

    'relationship_type_ex' => 'ex-partner',
    'relationship_type_ex_female' => 'eski kız arkadaş',
    'relationship_type_ex_male' => 'ex-boyfriend',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => ':name adlı kişinin eski kız arkadaşı',
    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',

    'relationship_type_parent' => 'parent',
    'relationship_type_parent_female' => 'anne',
    'relationship_type_parent_male' => 'father',
    'relationship_type_parent_with_name' => ':name’s parent',
    'relationship_type_parent_female_with_name' => ':name kişisinin annesi',
    'relationship_type_parent_male_with_name' => ':name’s father',

    'relationship_type_child' => 'child',
    'relationship_type_child_female' => 'kız',
    'relationship_type_child_male' => 'son',
    'relationship_type_child_with_name' => ':name’s child',
    'relationship_type_child_female_with_name' => ':name kişisinin kızı',
    'relationship_type_child_male_with_name' => ':name’s son',

    'relationship_type_stepparent' => 'step-parent',
    'relationship_type_stepparent_female' => 'üvey anne',
    'relationship_type_stepparent_male' => 'stepfather',
    'relationship_type_stepparent_with_name' => ':name’s step-parent',
    'relationship_type_stepparent_female_with_name' => ':name adlı kişinin üvey annesi',
    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',

    'relationship_type_stepchild' => 'stepchild',
    'relationship_type_stepchild_female' => 'üvey kız',
    'relationship_type_stepchild_male' => 'stepson',
    'relationship_type_stepchild_with_name' => ':name’s stepchild',
    'relationship_type_stepchild_female_with_name' => ':name adlı kişinin üvey kızı',
    'relationship_type_stepchild_male_with_name' => ':name’s stepson',

    'relationship_type_sibling' => 'sibling',
    'relationship_type_sibling_female' => 'kız kardeş',
    'relationship_type_sibling_male' => 'brother',
    'relationship_type_sibling_with_name' => ':name’s sibling',
    'relationship_type_sibling_female_with_name' => ':name kişisinin kız kardeşi',
    'relationship_type_sibling_male_with_name' => ':name’s brother',

    'relationship_type_grandparent' => 'grandparent',
    'relationship_type_grandparent_female' => 'grandmother',
    'relationship_type_grandparent_male' => 'grandfather',
    'relationship_type_grandparent_with_name' => ':name’s grandparent',
    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',

    'relationship_type_grandchild' => 'grandchild',
    'relationship_type_grandchild_female' => 'granddaughter',
    'relationship_type_grandchild_male' => 'grandson',
    'relationship_type_grandchild_with_name' => ':name’s grandchild',
    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
    'relationship_type_grandchild_male_with_name' => ':name’s grandson',

    'relationship_type_uncle' => 'amca/dayı',
    'relationship_type_uncle_female' => 'hala/teyze',
    'relationship_type_uncle_male' => 'uncle',
    'relationship_type_uncle_with_name' => ':name kişisinin amcası/dayısı',
    'relationship_type_uncle_female_with_name' => ':name kişisinin halası/teyzesi',
    'relationship_type_uncle_male_with_name' => ':name’s uncle',

    'relationship_type_nephew' => 'yeğen',
    'relationship_type_nephew_female' => 'yeğen',
    'relationship_type_nephew_male' => 'nephew',
    'relationship_type_nephew_with_name' => ':name kişisinin yeğeni',
    'relationship_type_nephew_female_with_name' => ':name kişisinin yeğeni',
    'relationship_type_nephew_male_with_name' => ':name’s nephew',

    'relationship_type_cousin' => 'kuzen',
    'relationship_type_cousin_female' => 'kuzen',
    'relationship_type_cousin_male' => 'cousin',
    'relationship_type_cousin_with_name' => ':name kişisinin kuzeni',
    'relationship_type_cousin_female_with_name' => ':name kişisinin kuzeni',
    'relationship_type_cousin_male_with_name' => ':name’s cousin',

    'relationship_type_godfather' => 'godparent',
    'relationship_type_godfather_female' => 'vaftiz anası',
    'relationship_type_godfather_male' => 'godfather',
    'relationship_type_godfather_with_name' => ':name’s godparent',
    'relationship_type_godfather_female_with_name' => ':name kişisinin vaftiz anası',
    'relationship_type_godfather_male_with_name' => ':name’s godfather',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'vaftiz kızı',
    'relationship_type_godson_male' => 'godson',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => ':name kişisinin vaftiz kızı',
    'relationship_type_godson_male_with_name' => ':name’s godson',

    'relationship_type_friend' => 'arkadaş',
    'relationship_type_friend_female' => 'arkadaş',
    'relationship_type_friend_male' => 'friend',
    'relationship_type_friend_with_name' => ':name kişisinin arkadaşı',
    'relationship_type_friend_female_with_name' => ':name kişisinin arkadaşı',
    'relationship_type_friend_male_with_name' => ':name’s friend',

    'relationship_type_bestfriend' => 'en iyi arkadaş',
    'relationship_type_bestfriend_female' => 'en iyi arkadaş',
    'relationship_type_bestfriend_male' => 'best friend',
    'relationship_type_bestfriend_with_name' => ':name kişisinin en iyi arkadaşı',
    'relationship_type_bestfriend_female_with_name' => ':name kişisinin en iyi arkadaşı',
    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',

    'relationship_type_colleague' => 'iş arkadaşı',
    'relationship_type_colleague_female' => 'iş arkadaşı',
    'relationship_type_colleague_male' => 'colleague',
    'relationship_type_colleague_with_name' => ':name kişisinin iş arkadaşı',
    'relationship_type_colleague_female_with_name' => ':name kişisinin iş arkadaşı',
    'relationship_type_colleague_male_with_name' => ':name’s colleague',

    'relationship_type_boss' => 'patron',
    'relationship_type_boss_female' => 'patron',
    'relationship_type_boss_male' => 'boss',
    'relationship_type_boss_with_name' => ':name kişisinin patronu',
    'relationship_type_boss_female_with_name' => ':name kişisinin patronu',
    'relationship_type_boss_male_with_name' => ':name’s boss',

    'relationship_type_subordinate' => 'altında çalışan',
    'relationship_type_subordinate_female' => 'altında çalışan',
    'relationship_type_subordinate_male' => 'subordinate',
    'relationship_type_subordinate_with_name' => ':name kişisinin altında çalışan',
    'relationship_type_subordinate_female_with_name' => ':name kişisinin altında çalışan',
    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',

    'relationship_type_mentor' => 'danışman',
    'relationship_type_mentor_female' => 'danışman',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => ':name kişisinin danışmanı',
    'relationship_type_mentor_female_with_name' => ':name kişisinin danışmanı',
    'relationship_type_mentor_male_with_name' => ':name’s mentor',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'protégé',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => ':name’s protégé',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex-spouse',
    'relationship_type_ex_husband_female' => 'eski karı',
    'relationship_type_ex_husband_male' => 'ex-husband',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => ':name kişisinin eski karısı',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',

    // emotions
    'emotion_primary_love' => 'Aşk',
    'emotion_primary_joy' => 'Sevinç',
    'emotion_primary_surprise' => 'Sürpriz',
    'emotion_primary_anger' => 'Öfke',
    'emotion_primary_sadness' => 'Üzüntü',
    'emotion_primary_fear' => 'Korku',

    'emotion_secondary_affection' => 'İlgi',
    'emotion_secondary_lust' => 'Arzu',
    'emotion_secondary_longing' => 'Hasret',
    'emotion_secondary_cheerfulness' => 'Neşe',
    'emotion_secondary_zest' => 'Keyif',
    'emotion_secondary_contentment' => 'Hoşnutluk',
    'emotion_secondary_pride' => 'Onur',
    'emotion_secondary_optimism' => 'İyimserlik',
    'emotion_secondary_enthrallment' => 'Büyülenme',
    'emotion_secondary_relief' => 'Rahatlama',
    'emotion_secondary_surprise' => 'Sürpriz',
    'emotion_secondary_irritation' => 'Rahatsızlık',
    'emotion_secondary_exasperation' => 'Çileden çıkma',
    'emotion_secondary_rage' => 'Hiddet',
    'emotion_secondary_disgust' => 'İğrenti',
    'emotion_secondary_envy' => 'İmrenme',
    'emotion_secondary_suffering' => 'Acı çekme',
    'emotion_secondary_sadness' => 'Üzüntü',
    'emotion_secondary_disappointment' => 'Hayal Kırıklığı',
    'emotion_secondary_shame' => 'Utanma',
    'emotion_secondary_neglect' => 'İhmal',
    'emotion_secondary_sympathy' => 'Sempati',
    'emotion_secondary_horror' => 'Korku',
    'emotion_secondary_nervousness' => 'Tedirginlik',

    'emotion_adoration' => 'Tapma',
    'emotion_affection' => 'İlgi',
    'emotion_love' => 'Aşk',
    'emotion_fondness' => 'Düşkünlük',
    'emotion_liking' => 'Beğeni',
    'emotion_attraction' => 'Cazibe',
    'emotion_caring' => 'Önemseme',
    'emotion_tenderness' => 'Hassasiyet',
    'emotion_compassion' => 'Şefkat',
    'emotion_sentimentality' => 'Duyarlılık',
    'emotion_arousal' => 'Uyarılma',
    'emotion_desire' => 'Arzu',
    'emotion_lust' => 'İhtiras',
    'emotion_passion' => 'Tutku',
    'emotion_infatuation' => 'Sevdalanma',
    'emotion_longing' => 'Hasret',
    'emotion_amusement' => 'Eğlence',
    'emotion_bliss' => 'Saadet',
    'emotion_cheerfulness' => 'Neşe',
    'emotion_gaiety' => 'Sevinç',
    'emotion_glee' => 'Keyif',
    'emotion_jolliness' => 'Neşe',
    'emotion_joviality' => 'Neşe',
    'emotion_joy' => 'Neşe',
    'emotion_delight' => 'Keyif',
    'emotion_enjoyment' => 'Hoşnutluk',
    'emotion_gladness' => 'Memnuniyet',
    'emotion_happiness' => 'Mutluluk',
    'emotion_jubilation' => 'Coşku',
    'emotion_elation' => 'Kıvanç',
    'emotion_satisfaction' => 'Tatmin olma',
    'emotion_ecstasy' => 'Zevk',
    'emotion_euphoria' => 'Öfori',
    'emotion_enthusiasm' => 'Heves',
    'emotion_zeal' => 'Gayret',
    'emotion_zest' => 'Keyif',
    'emotion_excitement' => 'Heyecan',
    'emotion_thrill' => 'Heyecan',
    'emotion_exhilaration' => 'Neşe',
    'emotion_contentment' => 'Hoşnutluk',
    'emotion_pleasure' => 'Zevk',
    'emotion_pride' => 'Onur',
    'emotion_eagerness' => 'Heves',
    'emotion_hope' => 'Umut',
    'emotion_optimism' => 'İyimserlik',
    'emotion_enthrallment' => 'Büyülenme',
    'emotion_rapture' => 'Kendinden geçme',
    'emotion_relief' => 'Rahatlama',
    'emotion_amazement' => 'Şaşkınlık',
    'emotion_surprise' => 'Sürpriz',
    'emotion_astonishment' => 'Hayret',
    'emotion_aggravation' => 'Çileden çıkma',
    'emotion_irritation' => 'Rahatsızlık',
    'emotion_agitation' => 'Kışkırtma',
    'emotion_annoyance' => 'Rahatsızlık',
    'emotion_grouchiness' => 'Huysuzluk',
    'emotion_grumpiness' => 'Somurtkanlık',
    'emotion_exasperation' => 'Çileden çıkma',
    'emotion_frustration' => 'Düş kırıklığı',
    'emotion_anger' => 'Öfke',
    'emotion_rage' => 'Hiddet',
    'emotion_outrage' => 'Hakaret',
    'emotion_fury' => 'Öfke',
    'emotion_wrath' => 'Gazap',
    'emotion_hostility' => 'Düşmanlık',
    'emotion_ferocity' => 'Vahşilik',
    'emotion_bitterness' => 'Keskinlik',
    'emotion_hate' => 'Nefret',
    'emotion_loathing' => 'İğrenme',
    'emotion_scorn' => 'Aşağılama',
    'emotion_spite' => 'Nispet',
    'emotion_vengefulness' => 'İntikamcılık',
    'emotion_dislike' => 'Beğenmeme',
    'emotion_resentment' => 'Gücenme',
    'emotion_disgust' => 'İğrenme',
    'emotion_revulsion' => 'Uzaklaşma',
    'emotion_contempt' => 'Küçümseme',
    'emotion_envy' => 'İmrenme',
    'emotion_jealousy' => 'Kıskançlık',
    'emotion_agony' => 'Acı çekme',
    'emotion_suffering' => 'Acı çekme',
    'emotion_hurt' => 'Acı',
    'emotion_anguish' => 'Izdırap',
    'emotion_depression' => 'Depresyon',
    'emotion_despair' => 'Ümitsizlik',
    'emotion_hopelessness' => 'Umutsuzluk',
    'emotion_gloom' => 'Kasvet',
    'emotion_glumness' => 'Asık suratlılık',
    'emotion_sadness' => 'Üzüntü',
    'emotion_unhappiness' => 'Mutsuzluk',
    'emotion_grief' => 'Keder',
    'emotion_sorrow' => 'Üzüntü',
    'emotion_woe' => 'Gam',
    'emotion_misery' => 'Sefalet',
    'emotion_melancholy' => 'Melankoli',
    'emotion_dismay' => 'Dehşet',
    'emotion_disappointment' => 'Hayal kırıklığı',
    'emotion_displeasure' => 'Hoşnutsuzluk',
    'emotion_guilt' => 'Suçluluk',
    'emotion_shame' => 'Utanma',
    'emotion_regret' => 'Pişman olma',
    'emotion_remorse' => 'Vicdan azabı',
    'emotion_alienation' => 'Yabancılaşma',
    'emotion_isolation' => 'İzolasyon',
    'emotion_neglect' => 'İhmal',
    'emotion_loneliness' => 'Yalnızlık',
    'emotion_rejection' => 'Reddedilme',
    'emotion_homesickness' => 'Sıla hasreti',
    'emotion_defeat' => 'Yenilgi',
    'emotion_dejection' => 'Keyifsizlik',
    'emotion_insecurity' => 'Güvensizlik',
    'emotion_embarrassment' => 'Mahçubiyet',
    'emotion_humiliation' => 'Aşağılanma',
    'emotion_insult' => 'Hakaret',
    'emotion_pity' => 'Acıma',
    'emotion_sympathy' => 'Sempati',
    'emotion_alarm' => 'Alarm',
    'emotion_shock' => 'Şok',
    'emotion_fear' => 'Korku',
    'emotion_fright' => 'Korku',
    'emotion_horror' => 'Korku',
    'emotion_terror' => 'Dehşet',
    'emotion_panic' => 'Panik',
    'emotion_hysteria' => 'Histeri',
    'emotion_mortification' => 'Küçük düşme',
    'emotion_anxiety' => 'Kaygı',
    'emotion_nervousness' => 'Tedirginlik',
    'emotion_tenseness' => 'Gerginlik',
    'emotion_uneasiness' => 'Huzursuzluk',
    'emotion_apprehension' => 'Kaygı',
    'emotion_worry' => 'Endişe',
    'emotion_distress' => 'Sıkıntı',
    'emotion_dread' => 'Korku',

    // weather
    'weather_sunny' => 'Sunny',
    'weather_clear' => 'Clear',
    'weather_clear-day' => 'Clear',
    'weather_clear-night' => 'Gece hava açık',
    'weather_light-drizzle' => 'Light drizzle',
    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
    'weather_patchy-light-rain' => 'Patchy light rain',
    'weather_light-rain' => 'Light rain',
    'weather_moderate-rain-at-times' => 'Moderate rain at times',
    'weather_moderate-rain' => 'Moderate rain',
    'weather_patchy-rain-possible' => 'Patchy rain possible',
    'weather_heavy-rain-at-times' => 'Heavy rain at times',
    'weather_heavy-rain' => 'Heavy rain',
    'weather_light-freezing-rain' => 'Light freezing rain',
    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
    'weather_light-sleet' => 'Light sleet',
    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
    'weather_light-rain-shower' => 'Light rain shower',
    'weather_torrential-rain-shower' => 'Torrential rain shower',
    'weather_rain' => 'Yağmur',
    'weather_snow' => 'Kar',
    'weather_blowing-snow' => 'Blowing snow',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'Light snow',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Moderate snow',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Heavy snow',
    'weather_light-snow-showers' => 'Light snow showers',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'Karla karışık yağmur',
    'weather_wind' => 'Rüzgar',
    'weather_fog' => 'Sis',
    'weather_freezing-fog' => 'Freezing fog',
    'weather_mist' => 'Mist',
    'weather_blizzard' => 'Blizzard',
    'weather_overcast' => 'Overcast',
    'weather_cloudy' => 'Bulutlu',
    'weather_partly-cloudy-day' => 'Partly cloudy',
    'weather_partly-cloudy-night' => 'Partly cloudy',
    'weather_freezing-drizzle' => 'Freezing drizzle',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Şu anki hava durumu',

    // dav
    'dav_contacts' => 'Kişiler',
    'dav_contacts_description' => ':name kişisinin kişileri',
    'dav_birthdays' => 'Doğum Günleri',
    'dav_birthdays_description' => ':name kişisinin kişilerinin doğum günleri',
    'dav_tasks' => 'Görevler',
    'dav_tasks_description' => ':name kişisinin görevleri',

    // contact list
    'contact_list_avatar' => 'Profil Resmi',
    'contact_list_name' => 'İletişim',
    'contact_list_description' => 'Açıklama',

];
